==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/AzureDatabricksDeltaLakeImportCommandArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.AzureDatabricksDeltaLakeImportCommandArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Azure Databricks Delta Lake import command settings.
 * @property dateFormat Specify the date format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
 * @property timestampFormat Specify the timestamp format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
 * @property type The import setting type.
 * Expected value is 'AzureDatabricksDeltaLakeImportCommand'.
 */
public data class AzureDatabricksDeltaLakeImportCommandArgs(
    public val dateFormat: Output<Any>? = null,
    public val timestampFormat: Output<Any>? = null,
    public val type: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.AzureDatabricksDeltaLakeImportCommandArgs> {
    override fun toJava():
        com.pulumi.azurenative.datafactory.inputs.AzureDatabricksDeltaLakeImportCommandArgs =
        com.pulumi.azurenative.datafactory.inputs.AzureDatabricksDeltaLakeImportCommandArgs.builder()
            .dateFormat(dateFormat?.applyValue({ args0 -> args0 }))
            .timestampFormat(timestampFormat?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureDatabricksDeltaLakeImportCommandArgs].
 */
@PulumiTagMarker
public class AzureDatabricksDeltaLakeImportCommandArgsBuilder internal constructor() {
    private var dateFormat: Output<Any>? = null

    private var timestampFormat: Output<Any>? = null

    private var type: Output<String>? = null

    /**
     * @param value Specify the date format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
     */
    @JvmName("ybhcodsfxpmxrmsh")
    public suspend fun dateFormat(`value`: Output<Any>) {
        this.dateFormat = value
    }

    /**
     * @param value Specify the timestamp format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
     */
    @JvmName("qsjnaycmohmseoaa")
    public suspend fun timestampFormat(`value`: Output<Any>) {
        this.timestampFormat = value
    }

    /**
     * @param value The import setting type.
     * Expected value is 'AzureDatabricksDeltaLakeImportCommand'.
     */
    @JvmName("jpcdwsxmrhxjlfcq")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Specify the date format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
     */
    @JvmName("spfgxbqicanbtkkb")
    public suspend fun dateFormat(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dateFormat = mapped
    }

    /**
     * @param value Specify the timestamp format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
     */
    @JvmName("jykbabeckfteuwoe")
    public suspend fun timestampFormat(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timestampFormat = mapped
    }

    /**
     * @param value The import setting type.
     * Expected value is 'AzureDatabricksDeltaLakeImportCommand'.
     */
    @JvmName("joutqoyjxsntbtuv")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): AzureDatabricksDeltaLakeImportCommandArgs =
        AzureDatabricksDeltaLakeImportCommandArgs(
            dateFormat = dateFormat,
            timestampFormat = timestampFormat,
            type = type ?: throw PulumiNullFieldException("type"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/AzureDatabricksDeltaLakeImportCommandArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.AzureDatabricksDeltaLakeImportCommandArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Azure Databricks Delta Lake import command settings.
 * @property dateFormat Specify the date format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
 * @property timestampFormat Specify the timestamp format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
 * @property type The import setting type.
 * Expected value is 'AzureDatabricksDeltaLakeImportCommand'.
 */
public data class AzureDatabricksDeltaLakeImportCommandArgs(
    public val dateFormat: Output<Any>? = null,
    public val timestampFormat: Output<Any>? = null,
    public val type: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.AzureDatabricksDeltaLakeImportCommandArgs> {
    override fun toJava():
        com.pulumi.azurenative.datafactory.inputs.AzureDatabricksDeltaLakeImportCommandArgs =
        com.pulumi.azurenative.datafactory.inputs.AzureDatabricksDeltaLakeImportCommandArgs.builder()
            .dateFormat(dateFormat?.applyValue({ args0 -> args0 }))
            .timestampFormat(timestampFormat?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureDatabricksDeltaLakeImportCommandArgs].
 */
@PulumiTagMarker
public class AzureDatabricksDeltaLakeImportCommandArgsBuilder internal constructor() {
    private var dateFormat: Output<Any>? = null

    private var timestampFormat: Output<Any>? = null

    private var type: Output<String>? = null

    /**
     * @param value Specify the date format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
     */
    @JvmName("ooexnfpojlhakoiv")
    public suspend fun dateFormat(`value`: Output<Any>) {
        this.dateFormat = value
    }

    /**
     * @param value Specify the timestamp format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
     */
    @JvmName("okqmsyfoonkjagnj")
    public suspend fun timestampFormat(`value`: Output<Any>) {
        this.timestampFormat = value
    }

    /**
     * @param value The import setting type.
     * Expected value is 'AzureDatabricksDeltaLakeImportCommand'.
     */
    @JvmName("cvjjonjtcaosumqb")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Specify the date format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
     */
    @JvmName("uarnvsbicquxgtlg")
    public suspend fun dateFormat(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dateFormat = mapped
    }

    /**
     * @param value Specify the timestamp format for csv in Azure Databricks Delta Lake Copy. Type: string (or Expression with resultType string).
     */
    @JvmName("dmrbdmlblwijyxud")
    public suspend fun timestampFormat(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timestampFormat = mapped
    }

    /**
     * @param value The import setting type.
     * Expected value is 'AzureDatabricksDeltaLakeImportCommand'.
     */
    @JvmName("olunsydwmnffhvvh")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): AzureDatabricksDeltaLakeImportCommandArgs =
        AzureDatabricksDeltaLakeImportCommandArgs(
            dateFormat = dateFormat,
            timestampFormat = timestampFormat,
            type = type ?: throw PulumiNullFieldException("type"),
        )
}
